@@ -176,6 +176,10 @@ def dict_from_param(param):
         addList = str(param.opts['addList'])
         opts.update(dict(addList=addList))
 
+    if 'addText' in param.opts:
+        addText = str(param.opts['addText'])
+        opts.update(dict(addText=addText))
+
     if 'detlist' in param.opts:
         detlist = str(param.opts['detlist'])
         opts.update(dict(detlist=detlist))
@@ -265,6 +269,10 @@ def elt_to_dict(el):
         addList = eval(el.get('addList'))
         param.update(dict(addList=addList))
 
+    if 'addText' in el.attrib.keys():
+        addText = str(el.get('addText'))
+        param.update(dict(addText=addText))
+
     if 'limits' in el.attrib.keys():
         values = list(eval(el.get('limits')))  # make sure the evaluated values are returned as list (in case another
         # iterator type has been used)
@@ -380,8 +388,12 @@ def walk_xml_to_parameter(params=[], XML_elt=None):
             if 'group' not in param_type:  # covers 'group', custom 'groupmove'...
                 set_txt_from_elt(el, param_dict)
             else:
-                subparams = []
-                param_dict.update(dict(children=walk_xml_to_parameter(subparams, el)))
+                if len(el) == 0:
+                    children = []
+                else:
+                    subparams = []
+                    children = walk_xml_to_parameter(subparams, el)
+                param_dict.update(dict(children=children))
 
                 param_dict.update(dict(name=el.tag))
 
