@@ -1,5 +1,6 @@
-from PyQt5 import QtGui, QtWidgets, QtCore
-from PyQt5.QtCore import Qt, QObject, pyqtSlot, pyqtSignal
+from pymodaq.daq_utils.gui_utils.file_io import select_file
+from qtpy import QtGui, QtWidgets, QtCore
+from qtpy.QtCore import Qt, QObject, Slot, Signal
 
 import sys
 import os
@@ -7,14 +8,13 @@ import numpy as np
 import tables
 
 from pyqtgraph.parametertree import Parameter, ParameterTree
-from pymodaq.daq_utils.parameter import pymodaq_ptypes
-from pymodaq.daq_utils.plotting.viewer2D.viewer2D_basic import Viewer2DBasic
-from pymodaq.daq_utils.plotting.graph_items import ImageItem, TriangulationItem
+from pymodaq.daq_utils.plotting.data_viewers.viewer2D_basic import Viewer2DBasic
+from pymodaq.daq_utils.plotting.items.image import UniformImageItem, SpreadImageItem
 from pymodaq.daq_utils import daq_utils as utils
 from pymodaq.daq_utils.h5modules import H5Saver, browse_data, H5BrowserUtil
 from pymodaq.daq_utils import gui_utils as gutils
 
-from pymodaq.daq_utils.daq_utils import get_set_local_dir
+from pymodaq.daq_utils.config import get_set_local_dir, Config
 
 local_path = get_set_local_dir()
 navigator_path = os.path.join(local_path, 'navigator_temp_files')
@@ -27,12 +27,12 @@ Ntick = 128
 colors_red = np.array([(int(r), 0, 0) for r in np.linspace(0, 255, Ntick)])
 colors_green = np.array([(0, int(g), 0) for g in np.linspace(0, 255, Ntick)])
 colors_blue = np.array([(0, 0, int(b)) for b in np.linspace(0, 255, Ntick)])
-config = utils.load_config()
+config = Config()
 
 
 class Navigator(QObject):
-    log_signal = pyqtSignal(str)
-    sig_double_clicked = pyqtSignal(float, float)
+    log_signal = Signal(str)
+    sig_double_clicked = Signal(float, float)
 
     def __init__(self, parent=None, h5file_path=None):
         super().__init__(parent)
@@ -111,7 +111,7 @@ class Navigator(QObject):
         self.histo_action.setCheckable(True)
         self.histo_action.triggered.connect(self.show_histo)
 
-    @pyqtSlot(float, float)
+    @Slot(float, float)
     def move_at(self, posx, posy):
         if self.moveat_action.isChecked():
             self.sig_double_clicked.emit(posx, posy)
@@ -184,8 +184,9 @@ class Navigator(QObject):
                 self.settings.child('scans', pixmaps[0]['scan_name']).value())
 
     def load_data(self):
-        self.h5module_path = str(gutils.select_file(start_path=config['data_saving']['h5file']['save_path'],
-                                                    save=False, ext='h5'))
+        self.h5module_path = str(
+            select_file(start_path=config('data_saving', 'h5file', 'save_path'),
+                                                            save=False, ext='h5'))
         if self.h5module_path != '':
             self.settings.child('settings', 'filepath').setValue(self.h5module_path)
             if self.h5module is not None:
@@ -245,9 +246,9 @@ class Navigator(QObject):
                                 if flag:
                                     isadaptive = 'adaptive' in node.attrs['scan_subtype'].lower()
                                     if isadaptive:
-                                        im = TriangulationItem()
+                                        im = SpreadImageItem()
                                     else:
-                                        im = ImageItem()
+                                        im = UniformImageItem()
                                     im.setOpacity(1)
                                     # im.setOpts(axisOrder='row-major')
                                     self.viewer.image_widget.plotitem.addItem(im)
